@@ -3,6 +3,7 @@ pub mod dp {
 
     use itertools::structs::Combinations;
     use std::sync::RwLock;
+    use field_accessor::FieldAccessor;
 
     struct MultiCombination<I: Iterator> {
         combs: Vec<Combinations<I>>,
@@ -29,7 +30,7 @@ pub mod dp {
     use std::collections::HashMap;
     use std::sync::Arc;
 
-    #[derive(Clone, Debug)]
+    #[derive(Clone, Debug, FieldAccessor)]
     pub struct AnswerElement {
         pub answer_arr: Vec<(Vec<i32>, Vec<i32>)>,
         pub keys_remainder: Vec<i32>,
@@ -88,7 +89,6 @@ pub mod dp {
                     target_str
                 ));
             }
-            
             s.push(format!(
                 "pattern{number:^width$}=> [{v}],\n               keys remainder    : {k}\n               targets remainder : {t}\n",
                 number = i + 1,
@@ -145,22 +145,22 @@ pub mod dp {
         let offset: i32 = match offset {
             Some(x) => x,
             None => {
-                (max(arr.iter().min().unwrap().abs() + 1, min(value, 0).abs() + 1)) as u32 as i32
+                (max(arr.iter().min().unwrap().abs() + 1, min(value, 0).abs() + 1)) as i32
             }
         };
         let answer: Arc<RwLock<Vec<Vec<i32>>>> = Arc::new(RwLock::new(vec![]));
         if offset == 0 && arr.iter().min().unwrap() >= &0 && value >= 0 {
             let arr_pos = arr.iter().map(|e| *e as u32).collect::<Vec<u32>>();
-            let newdp: DpTable;
+            let _dp: DpTable;
             let dptable = match dptable {
                 Some(x) => x,
                 None => {
-                    newdp = _make_dp_table(&arr_pos, value as usize);
-                    &newdp
+                    _dp = _make_dp_table(&arr_pos, value as usize);
+                    &_dp
                 }
             };
             let result =
-                _find_subset_fast_only_positive(&arr_pos, value as usize, max_length, dptable);
+                _find_subsetsfast_only_positive(&arr_pos, value as usize, max_length, dptable);
             result.iter().for_each(|i| {
                 answer
                     .write()
@@ -196,7 +196,7 @@ pub mod dp {
                 }
             };
             let c = |i| {
-                let result = _find_subset_fast_only_positive(
+                let result = _find_subsetsfast_only_positive(
                     &_arr_pos,
                     (value + (i as i32 * offset)) as usize,
                     max_length,
@@ -335,7 +335,7 @@ pub mod dp {
         }
     }
 
-    fn _find_subset_fast_only_positive(
+    fn _find_subsetsfast_only_positive(
         arr: &Vec<u32>,
         value: usize,
         max_length: usize,
@@ -378,7 +378,7 @@ pub mod dp {
     /// This method assumes that the two vectors have Many-to-Many relationships.
     /// Each integer of the `keys` vector corresponds to the multiple integers of the `targets` vector.
     /// With this method, we can find combinations of the integers.
-    /// 
+    ///
     /// To avoid combinatorial explosion, some parameters need to be set.
     /// `max_key_length` is used to restrict the number of values in keys chosen.
     /// If `max_key_length` is 3, an answer's length is at most 3, such as `[1980 + 2980 + 3500], [1050]`
@@ -387,7 +387,7 @@ pub mod dp {
     /// If `use_all_keys` is true, an answer must contain all the elements of the keys.
     /// If `use_all_targets` is true, an answer must contain all the elements of the targets.
     /// When both `use_all_keys` and `use_all_targets` are true, the sum of the keys and the targets must be the same.
-    /// 
+    ///
     /// # Arguments
     /// * `keys` - An array.
     /// * `targets` - An array.
@@ -457,13 +457,28 @@ pub mod dp {
         keys.sort_unstable();
         targets.sort_unstable();
         let swap: bool;
-        let (keys, targets, max_key_length, max_target_length, use_all_keys, use_all_targets) = if keys.len() > targets.len() {
-            swap = true;
-            (targets, keys, max_target_length, max_key_length, use_all_targets, use_all_keys)
-        } else {
-            swap = false;
-            (keys, targets, max_key_length, max_target_length, use_all_keys, use_all_targets)
-        };
+        let (keys, targets, max_key_length, max_target_length, use_all_keys, use_all_targets) =
+            if keys.len() > targets.len() {
+                swap = true;
+                (
+                    targets,
+                    keys,
+                    max_target_length,
+                    max_key_length,
+                    use_all_targets,
+                    use_all_keys,
+                )
+            } else {
+                swap = false;
+                (
+                    keys,
+                    targets,
+                    max_key_length,
+                    max_target_length,
+                    use_all_keys,
+                    use_all_targets,
+                )
+            };
         use std::cmp::min;
         (0..min(keys.len(), targets.len())).for_each(|i| {
             sequence_matcher_core(
@@ -478,34 +493,35 @@ pub mod dp {
                 use_all_keys,
                 use_all_targets,
                 i,
-                vec![]
+                vec![],
             )
         });
-        let mut answer2: Vec<AnswerElement> = answer.read().unwrap().to_vec();
-        if swap{
-            answer2.iter_mut().for_each(|x| {
-                x.answer_arr.iter_mut().for_each(|y|{
-                    let a = y.0.clone();
-                    let b = y.1.clone();
-                    y.1 = a;
-                    y.0 = b;
+        let mut answer_vec: Vec<AnswerElement> = answer.read().unwrap().to_vec();
+        if swap {
+            answer_vec.iter_mut().for_each(|x| {
+                x.answer_arr.iter_mut().for_each(|y| {
+                    mem::swap(&mut y.0, &mut y.1);
                 });
-                let a = x.keys_remainder.clone();
-                let b = x.targets_remainder.clone();
-                x.keys_remainder = b;
-                x.targets_remainder = a;
+                match x.swap(&"keys_remainder".to_string(), &"targets_remainder".to_string()) {
+                    Ok(_) => {},
+                    Err(e) => {
+                        panic!("{}", e);
+                    }
+                }
             });
         }
-        for i in 0..answer2.len() {
-            answer2[i].answer_arr.sort_unstable_by_key(|k| k.0.iter().sum::<i32>());
-            answer2[i].answer_arr.sort_unstable_by_key(|k| k.0.len());
+        for i in 0..answer_vec.len() {
+            answer_vec[i]
+                .answer_arr
+                .sort_unstable_by_key(|k| k.0.iter().sum::<i32>());
+            answer_vec[i].answer_arr.sort_unstable_by_key(|k| k.0.len());
         }
-        answer2.sort_unstable();
-        answer2.dedup();
-        if answer2.len() == 0 {
+        answer_vec.sort_unstable();
+        answer_vec.dedup();
+        if answer_vec.len() == 0 {
             println!("Can't find any combination.");
         }
-        Ok(answer2[..min(n_candidates, answer2.len())].to_vec())
+        Ok(answer_vec[..min(n_candidates, answer_vec.len())].to_vec())
     }
 
     fn sequence_matcher_core(
@@ -520,7 +536,7 @@ pub mod dp {
         use_all_keys: bool,
         use_all_targets: bool,
         max_depth: usize,
-        last_key: Vec<i32>
+        last_key: Vec<i32>,
     ) -> () {
         use itertools::Itertools;
         use std::cmp::max;
@@ -530,14 +546,14 @@ pub mod dp {
             return;
         }
 
-        let add:  bool = match (use_all_keys, use_all_targets) {
+        let add: bool = match (use_all_keys, use_all_targets) {
             (true, true) => {
                 let add = match (keys.len() == 0, targets.len() == 0) {
                     (true, true) => true,
                     _ => false,
                 };
                 add
-            },
+            }
             (true, false) => {
                 let add = match (keys.len() == 0, targets.len() == 0) {
                     (true, true) => true,
@@ -545,7 +561,7 @@ pub mod dp {
                     _ => false,
                 };
                 add
-            },
+            }
             (false, true) => {
                 let add = match (keys.len() == 0, targets.len() == 0) {
                     (true, true) => true,
@@ -553,7 +569,7 @@ pub mod dp {
                     _ => false,
                 };
                 add
-            },
+            }
             (false, false) => {
                 let add = match (keys.len() == 0, targets.len() == 0) {
                     (true, true) => true,
@@ -562,13 +578,17 @@ pub mod dp {
                     _ => false,
                 };
                 add
-            },
+            }
         };
 
         if add {
             group.sort_unstable_by_key(|k| k.0.iter().sum::<i32>());
             group.sort_unstable_by_key(|k| k.0.len());
-            let elem = AnswerElement {answer_arr: group.clone(), keys_remainder: keys.clone(), targets_remainder: targets.clone()};
+            let elem = AnswerElement {
+                answer_arr: group.clone(),
+                keys_remainder: keys.clone(),
+                targets_remainder: targets.clone(),
+            };
             if answer.read().unwrap().contains(&elem) {
                 return;
             } else {
@@ -583,7 +603,6 @@ pub mod dp {
             return;
         }
         targets.sort_unstable();
-        let mut combs = vec![];
         keys.sort_unstable();
         keys.reverse();
         let dp: DpTable;
@@ -596,10 +615,10 @@ pub mod dp {
                 dp = _make_dp_table(&arr_pos, max_value as usize);
                 Some(&dp)
             } else {
-                offset = (max(
+                offset = max(
                     targets.iter().min().unwrap().abs() + 1,
                     keys.iter().fold(0, |sum, x| min(sum, x + sum)).abs() + 1,
-                )) as u32 as i32;
+                );
                 arr_pos = targets
                     .iter()
                     .map(|e| (e + offset) as u32)
@@ -613,6 +632,7 @@ pub mod dp {
                 Some(&dp)
             };
         keys.reverse();
+        let mut combs = vec![];
         for i in 1..min(max_key_length, keys.len()) + 1 {
             combs.push(keys.clone().into_iter().enumerate().combinations(i))
         }
@@ -623,7 +643,7 @@ pub mod dp {
                 if sum_key < last_key.iter().sum() && i.len() == last_key.len() {
                     return;
                 }
-                let mut set_ = {
+                let mut sets = {
                     match hashmap_fs.try_write() {
                         Ok(mut v) => v
                             .entry((targets.clone(), sum_key))
@@ -646,31 +666,31 @@ pub mod dp {
                         ),
                     }
                 };
-                if set_.len() == 0 {
+                if sets.len() == 0 {
                     return;
                 }
-                set_.dedup();
-                let mut keys3: Vec<i32> = keys.clone();
+                sets.dedup();
+                let mut keys_removed: Vec<i32> = keys.clone();
                 let vec_key: Vec<i32> = i
                     .iter()
                     .enumerate()
-                    .map(|(j2, j)| keys3.remove(j.0 - j2))
+                    .map(|(j2, j)| keys_removed.remove(j.0 - j2))
                     .collect();
-                set_.iter().for_each(|set| {
+                sets.iter().for_each(|set| {
                     if set.len() == 0 {
                         return;
                     }
-                    let mut keys4 = keys3.clone();
-                    let mut targets3 = targets.clone();
-                    let mut group3 = group.clone();
-                    group3.push((vec_key.clone(), set.clone()));
+                    let mut keys_for_next = keys_removed.clone();
+                    let mut targets_for_next = targets.clone();
+                    let mut group_for_next = group.clone();
+                    group_for_next.push((vec_key.clone(), set.clone()));
                     set.iter().for_each(|j| {
-                        vec_remove(&mut targets3, *j);
+                        vec_remove(&mut targets_for_next, *j);
                     });
                     sequence_matcher_core(
-                        &mut keys4,
-                        &mut targets3,
-                        &mut group3,
+                        &mut keys_for_next,
+                        &mut targets_for_next,
+                        &mut group_for_next,
                         &mut answer.clone(),
                         max_key_length,
                         max_target_length,
@@ -679,7 +699,7 @@ pub mod dp {
                         use_all_keys,
                         use_all_targets,
                         max_depth,
-                        vec_key.clone()
+                        vec_key.clone(),
                     );
                 });
             });
@@ -689,7 +709,7 @@ pub mod dp {
                 if sum_key < last_key.iter().sum() && i.len() == last_key.len() {
                     return;
                 }
-                let mut set_ = {
+                let mut sets = {
                     match hashmap_fs.try_write() {
                         Ok(mut v) => v
                             .entry((targets.clone(), sum_key))
@@ -712,31 +732,31 @@ pub mod dp {
                         ),
                     }
                 };
-                if set_.len() == 0 {
+                if sets.len() == 0 {
                     return;
                 }
-                set_.dedup();
-                let mut keys3: Vec<i32> = keys.clone();
+                sets.dedup();
+                let mut keys_removed: Vec<i32> = keys.clone();
                 let vec_key: Vec<i32> = i
                     .iter()
                     .enumerate()
-                    .map(|(j2, j)| keys3.remove(j.0 - j2))
+                    .map(|(j2, j)| keys_removed.remove(j.0 - j2))
                     .collect();
-                set_.par_iter().for_each(|set| {
+                sets.par_iter().for_each(|set| {
                     if set.len() == 0 {
                         return;
                     }
-                    let mut keys4 = keys3.clone();
-                    let mut targets3 = targets.clone();
-                    let mut group3 = group.clone();
-                    group3.push((vec_key.clone(), set.clone()));
+                    let mut keys_for_next = keys_removed.clone();
+                    let mut targets_for_next = targets.clone();
+                    let mut group_for_next = group.clone();
+                    group_for_next.push((vec_key.clone(), set.clone()));
                     set.iter().for_each(|j| {
-                        vec_remove(&mut targets3, *j);
+                        vec_remove(&mut targets_for_next, *j);
                     });
                     sequence_matcher_core(
-                        &mut keys4,
-                        &mut targets3,
-                        &mut group3,
+                        &mut keys_for_next,
+                        &mut targets_for_next,
+                        &mut group_for_next,
                         &mut answer.clone(),
                         max_key_length,
                         max_target_length,
@@ -745,7 +765,7 @@ pub mod dp {
                         use_all_keys,
                         use_all_targets,
                         max_depth,
-                        vec_key.clone()
+                        vec_key.clone(),
                     );
                 });
             });
@@ -754,7 +774,11 @@ pub mod dp {
             if group.len() == 0 {
                 return;
             }
-            let elem = AnswerElement {answer_arr: group.clone(), keys_remainder: keys.clone(), targets_remainder: targets.clone()};
+            let elem = AnswerElement {
+                answer_arr: group.clone(),
+                keys_remainder: keys.clone(),
+                targets_remainder: targets.clone(),
+            };
             answer.write().unwrap().push(elem.clone());
         }
         ()
@@ -772,7 +796,10 @@ pub mod dp {
             true,
         )
         .unwrap();
-        assert_eq!(answer[0].answer_arr, vec![(vec![-950, 10000], vec![50, 4000, 5000]),]);
+        assert_eq!(
+            answer[0].answer_arr,
+            vec![(vec![-950, 10000], vec![50, 4000, 5000]),]
+        );
 
         let answer = sequence_matcher(
             &mut vec![6, 7, 3, 2, -9, -3, 8, 3, 6, -10],
